==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/FormatSummaryTextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSummaryTextEventArgsDescription } from "./FormatSummaryTextEventArgsDescription";
/**
 * @hidden
 */
var FormatSummaryTextEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatSummaryTextEventArgsDescriptionMetadata, _super);
    function FormatSummaryTextEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatSummaryTextEventArgsDescriptionMetadata.b = function (a) {
        if (FormatSummaryTextEventArgsDescriptionMetadata.a == null) {
            FormatSummaryTextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatSummaryTextEventArgsDescriptionMetadata.c(FormatSummaryTextEventArgsDescriptionMetadata.a);
        }
        if (a.k(FormatSummaryTextEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(FormatSummaryTextEventArgsDescriptionMetadata.a);
    };
    FormatSummaryTextEventArgsDescriptionMetadata.c = function (a) {
        a.item("Field", "String");
        a.item("DisplayName", "String");
        a.item("SummaryResultRef", "(w:SummaryResult,wf:SummaryResult)DataRef");
        a.item("FormattedResult", "String");
        a.item("FormattedText", "String");
    };
    FormatSummaryTextEventArgsDescriptionMetadata.d = function (a) {
        FormatSummaryTextEventArgsDescriptionMetadata.b(a);
        a.ad("FormatSummaryTextEventArgs", function () { return new FormatSummaryTextEventArgsDescription(); });
        a.ac("FormatSummaryTextEventArgs", FormatSummaryTextEventArgsDescriptionMetadata.a);
    };
    FormatSummaryTextEventArgsDescriptionMetadata.$t = markType(FormatSummaryTextEventArgsDescriptionMetadata, 'FormatSummaryTextEventArgsDescriptionMetadata');
    FormatSummaryTextEventArgsDescriptionMetadata.a = null;
    return FormatSummaryTextEventArgsDescriptionMetadata;
}(Base));
export { FormatSummaryTextEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/FormatSummaryTextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatSummaryTextEventArgsDescription } from "./FormatSummaryTextEventArgsDescription";
/**
 * @hidden
 */
var FormatSummaryTextEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FormatSummaryTextEventArgsDescriptionMetadata, _super);
    function FormatSummaryTextEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FormatSummaryTextEventArgsDescriptionMetadata.b = function (a) {
        if (FormatSummaryTextEventArgsDescriptionMetadata.a == null) {
            FormatSummaryTextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FormatSummaryTextEventArgsDescriptionMetadata.c(FormatSummaryTextEventArgsDescriptionMetadata.a);
        }
        if (a.k(FormatSummaryTextEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(FormatSummaryTextEventArgsDescriptionMetadata.a);
    };
    FormatSummaryTextEventArgsDescriptionMetadata.c = function (a) {
        a.item("Field", "String");
        a.item("DisplayName", "String");
        a.item("SummaryResultRef", "(w:SummaryResult,wf:SummaryResult)DataRef");
        a.item("FormattedResult", "String");
        a.item("FormattedText", "String");
    };
    FormatSummaryTextEventArgsDescriptionMetadata.d = function (a) {
        FormatSummaryTextEventArgsDescriptionMetadata.b(a);
        a.ae("FormatSummaryTextEventArgs", function () { return new FormatSummaryTextEventArgsDescription(); });
        a.ad("FormatSummaryTextEventArgs", FormatSummaryTextEventArgsDescriptionMetadata.a);
    };
    FormatSummaryTextEventArgsDescriptionMetadata.$t = markType(FormatSummaryTextEventArgsDescriptionMetadata, 'FormatSummaryTextEventArgsDescriptionMetadata');
    FormatSummaryTextEventArgsDescriptionMetadata.a = null;
    return FormatSummaryTextEventArgsDescriptionMetadata;
}(Base));
export { FormatSummaryTextEventArgsDescriptionMetadata };
